<?php
/**
 * This script manages the deletion of fields from a Ulaform form.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: ulaform/deletefield.php,v 1.27 2005/08/24 05:31:06 selsky Exp $
 */

@define('ULAFORM_BASE', dirname(__FILE__));
require_once ULAFORM_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$formname = $vars->get('formname');

if (is_null($formname)) {
    if ($vars->exists('field_id')) {
        $vars = $ulaform->getField($vars->get('form_id'), $vars->get('field_id'));
        $vars = &new Variables($vars);
    } else {
        $notification->push(_("No field specified."), 'horde.warning');
        $url = Util::addParameter(Horde::applicationUrl('fields.php'),
                                  array('form_id' => $vars->get('form_id')),
                                  null, false);
        header('Location: ' . $url);
        exit;
    }
}

/* Get the form object. */
$fieldform = Horde_Form::singleton('', $vars, _("Delete Field"));

/* Set up the form. */
$fieldform->setButtons(array(_("Delete"), _("Do not delete")));
$fieldform->addHidden('', 'field_id', 'int', true);
$fieldform->addHidden('', 'form_id', 'int', true);
$fieldform->addHidden('', 'field_name', 'text', false);
$fieldform->addVariable(_("Delete this field?"), 'field_name', 'text', false, true);

if ($vars->get('submitbutton') == _("Delete")) {
    $fieldform->validate($vars);

    if ($fieldform->isValid()) {
        $fieldform->getInfo($vars, $info);
        $del_field = $ulaform->deleteField($info['field_id']);
        if (is_a($del_field, 'PEAR_Error')) {
            Horde::logMessage($del_field, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Error deleting field. %s."), $del_field->getMessage()), 'horde.error');
        } else {
            $notification->push(sprintf(_("Field \"%s\" deleted."), $info['field_name']), 'horde.success');
            $url = Util::addParameter(Horde::applicationUrl('fields.php'),
                                      array('form_id' => $info['form_id']),
                                      null, false);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif ($vars->get('submitbutton') == _("Do not delete")) {
    $notification->push(_("Field not deleted."), 'horde.message');
    $url = Util::addParameter(Horde::applicationUrl('fields.php'),
                              array('form_id' => $vars->get('form_id')),
                              null, false);
    header('Location: ' . $url);
    exit;
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($fieldform, 'renderActive'), $renderer, $vars, 'deletefield.php', 'post');

$template->set('main', $main);
$template->set('menu', Ulaform::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require ULAFORM_TEMPLATES . '/common-header.inc';
echo $template->fetch(ULAFORM_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
