<?php
/**
 * The Ulaform script to add fields to a Ulaform form or to edit existing ones.
 * It recognises what extra parameters need to be instered for a particular
 * field and adjusts the form accordingly.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: ulaform/fields.php,v 1.41 2005/02/16 20:41:25 chuck Exp $
 */

@define('ULAFORM_BASE', dirname(__FILE__));
require_once ULAFORM_BASE . '/lib/base.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$formname = $vars->get('formname');
$field_id = $vars->get('field_id');
$form_id = $vars->get('form_id');
$old_field_type = $vars->get('old_field_type');

/* Check if a field is being edited. */
if ($field_id && !$formname) {
    $vars = $ulaform->getField($form_id, $vars->get('field_id'));
    $vars = &new Variables($vars);
}

/* Set up the form object. */
$fieldform = &Horde_Form::singleton('', $vars, _("Field Details"));

/* Set up the form. */
$fieldform->setButtons(_("Save Field"));
$fieldform->addHidden('', 'field_id', 'int', false);
$fieldform->addHidden('', 'form_id', 'int', false);
$fieldform->addHidden('', 'field_order', 'int', false);
$fieldform->addHidden('', 'old_field_type', 'text', false);
$fieldform->addVariable(_("Label"), 'field_label', 'text', true);
$fieldform->addVariable(_("Internal name"), 'field_name', 'text', false, false, _("Set this name if you have a particular reason to override the automatic internal naming of fields."));

/* Set up the field type selection, with a submit action. */
$fields = Ulaform::getFieldTypes();
$v = &$fieldform->addVariable(_("Type"), 'field_type', 'enum', true, false, null, array($fields, true));
$action = &Horde_Form_Action::factory('submit');
$v->setAction($action);
$v->setOption('trackchange', true);

$fieldform->addVariable(_("Required"), 'field_required', 'boolean', false);
$fieldform->addVariable(_("Read only"), 'field_readonly', 'boolean', false);
$fieldform->addVariable(_("Description"), 'field_desc', 'text', false);

/* Check if the submitted field type has extra parameters and set them up. */
$field_type = $vars->get('field_type');
$available_params = Ulaform::getFieldParams($field_type);
if (!is_null($vars->get('formname')) &&
    $vars->get($v->getVarName()) != $vars->get('__old_' . $v->getVarName()) &&
    !empty($available_params)) {
    $notification->push(_("This field type has extra parameters."), 'horde.message');
}
foreach ($available_params as $name => $param) {
    $field_id = 'field_params[' . $name . ']';
    $param['required'] = isset($param['required']) ? $param['required']
                                                   : null;
    $param['readonly'] = isset($param['readonly']) ? $param['readonly']
                                                   : null;
    $param['desc'] = isset($param['desc']) ? $param['desc']
                                           : null;

    $fieldform->addVariable($param['label'], $field_id, $param['type'], $param['required'], $param['readonly'], $param['desc']);
}

/* Set the current field type to the old field type var. */
$vars->set('old_field_type', $field_type);

if ($fieldform->validate($vars)) {
    /* Save field if valid and the current and old field type match. */
    $fieldform->getInfo($vars, $info);
    $save_field = $ulaform->saveField($info);
    if (is_a($save_field, 'PEAR_Error')) {
        Horde::logMessage($save_field, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Error saving field. %s."), $save_field->getMessage()), 'horde.error');
    } else {
        $notification->push(_("Field saved."), 'horde.success');
        $url = Horde::applicationUrl('fields.php', true);
        $url = Util::addParameter($url, array('form_id' => $info['form_id']),
                                  null, false);
        header('Location: ' . $url);
        exit;
    }
}

/* Get a field list. */
$fields_list = $ulaform->getFieldsList($form_id);
if (is_a($fields_list, 'PEAR_Error')) {
    /* Go back to forms if inexistant form_id. */
    $notification->push($fields_list->getMessage(), 'horde.error');
    header('Location: ' . Horde::applicationUrl('forms.php'));
    exit;
} elseif (empty($fields_list)) {
    /* Show a warning if no fields present. */
    $notification->push(_("No available fields."), 'horde.warning');
}

/* Set up the template fields. */
$template->set('menu', Ulaform::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

/* Set up the template action links. */
$actions = array();
$url = Horde::applicationUrl('genhtml.php');
$actions['html_url'] = Util::addParameter($url, 'form_id', $form_id);
$url = Horde::applicationUrl('display.php');
$actions['preview_url'] = Util::addParameter($url, 'form_id', $form_id);
$url = Horde::applicationUrl('sortfields.php');
$actions['sort_url'] = Util::addParameter($url, 'form_id', $form_id);
$template->set('actions', $actions);

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$inputform = Util::bufferOutput(array($fieldform, 'renderActive'), $renderer, $vars, 'fields.php', 'post');

$template->set('inputform', $inputform);

/* Set up the field list. */
$fieldproperties = array('name' => _("Name"), 'label' => _("Label"), 'type' => _("Type"), 'required' => _("Required"), 'readonly' => _("Read only"), 'desc' => _("Description"));
$template->set('fieldproperties', $fieldproperties);
$images = array('delete' => Horde::img('delete.png', _("Delete Field"), null, $registry->getImageDir('horde')),
                'edit' => Horde::img('edit.png', _("Edit Field"), '', $registry->getImageDir('horde')),
                'html' => Horde::img('html.png', _("Generate HTML")),
                'preview' => Horde::img('display.png', _("Preview")),
                'sort' => Horde::img('sort.png', _("Sort fields")));
$template->set('images', $images);
$template->set('fields', $fields_list, true);

/* Render the page. */
$title = _("Form Fields");
require ULAFORM_TEMPLATES . '/common-header.inc';
echo $template->fetch(ULAFORM_TEMPLATES . '/fields/fields.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
