<?php

require_once 'Horde/Perms.php';

/**
 * Ulaform Permissions Class
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: ulaform/lib/Perms.php,v 1.11 2005/05/11 00:33:59 selsky Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @package Ulaform
 */
class Ulaform_Perms extends Perms {

    /**
     * This function does the permission checking when using Ulaform.
     *
     * @param mixed  $in          A form_id or an array of form_id's to check
     *                            permission on.
     * @param string $filter      What type of check to do.
     * @param string $permission  What type of permission to check for.
     * @param string $key         The array key to use for checking.
     *
     * @return mixed  Depending on the type of check, either return a boolean
     *                to indicate permission for that form, or a filtered out
     *                array of form_id's.
     */
    function checkPermissions($in, $filter, $permission = PERMS_READ, $key = null)
    {
        global $conf, $ulaform;
        static $permsCache;

        $admin = Auth::isAdmin();
        /* Horde admin is always authorised. */
        if ($admin) {
            return $in;
        }

        $out = array();
        $userID = Auth::getAuth();
        switch ($filter) {
        /* Check permissions for a single form or for an array of forms. */
        case 'form':
            if (is_array($in)) {
                $id = serialize($in);
            } else {
                $id = $in;
                $in = array($in);
            }

            if (isset($permsCache[$id][$permission])) {
                return $permsCache[$id][$permission];
            }

            foreach ($in as $form_id => $form) {
                if (!is_null($key)) {
                    $form_id = $form[$key];
                }
                if ($this->hasPermission('ulaform:form:' . $form_id, $userID, $permission)) {
                    /* Cache and set into the $out array. */
                    $permsCache[$form_id][$permission] = true;
                    $out[$form_id] = $form;
                }
            }
            $permsCache[$id][$permission] = $out;
            break;

        default:
            /* For now default everything to false */
            $out = false;
        }

        return $out;
    }

}
