<?php
/**
 * The Ulaform:: class providing some support functions to the Ulaform module.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 * Copyright 2001-2005 Brent J. Nordquist <bjn@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: ulaform/lib/Ulaform.php,v 1.26 2005/07/03 02:26:15 selsky Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @author  Brent J. Nordquist <bjn@horde.org>
 * @since   Ulaform 0.1
 * @package Ulaform
 */
class Ulaform {

    function getActionInfo($action)
    {
        static $info = array();
        if (isset($info[$action])) {
            return $info[$action];
        }

        require_once dirname(__FILE__) . '/Action/' . $action . '.php';
        $class = 'Ulaform_Action_' . $action;
        $info[$action] = call_user_func(array($class, 'getInfo'));

        return $info[$action];
    }

    function getActionParams($action)
    {
        static $params = array();
        if (isset($params[$action])) {
            return $params[$action];
        }

        require_once dirname(__FILE__) . '/Action/' . $action . '.php';
        $class = 'Ulaform_Action_' . $action;
        $params[$action] = call_user_func(array($class, 'getParams'));

        return $params[$action];
    }

    /**
     * Fetch the available field types from the Horde_Form classes.
     *
     * @return array  The available field types.
     */
    function getFieldTypes()
    {
        static $available_fields = array();
        if (!empty($available_fields)) {
            return $available_fields;
        }

        /* Fetch the field type information from the Horde_Form classes. */
        $fields = Ulaform::getFieldTypesArray();

        /* Strip out the name element from the array. */
        foreach ($fields as $field_type => $info) {
            $available_fields[$field_type] = $info['name'];
        }

        /* Sort for display purposes. */
        asort($available_fields);

        return $available_fields;
    }

    /**
     * Fetch the full array for the field types, with params.
     *
     * @return array  The full field types array.
     */
    function getFieldTypesArray()
    {
        static $fields_array = array();
        if (!empty($fields_array)) {
            return $fields_array;
        }

        /* Fetch all declared classes. */
        $classes = get_declared_classes();

        /* Filter for the Horde_Form_Type classes. */
        foreach ($classes as $class) {
            if (strtolower(substr($class, 0, 16)) == 'horde_form_type_') {
                $field_type = substr($class, 16);
                /* Don't bother including the types that can not be handled
                   usefully by ulaform. */
                if ($field_type == 'invalid') {
                    continue;
                }
                $fields_array[$field_type] = @call_user_func(array('Horde_Form_Type_' . $field_type, 'about'));
            }
        }

        return $fields_array;
    }

    function getFieldParams($field_type)
    {
        $fields = Ulaform::getFieldTypesArray();

        /* Return null if there are no params for this field type. */
        if (!isset($fields[$field_type]['params'])) {
            return array();
        }

        return $fields[$field_type]['params'];
    }

    function getStringlistArray($string)
    {
        $string = str_replace("'", "\'", $string);
        $values = explode(',', $string);

        foreach ($values as $value) {
            $value = trim($value);
            $value_array[$value] = $value;
        }

        return $value_array;
    }

    /**
     * Build Ulaform's list of menu items.
     */
    function getMenu($returnType = 'object')
    {
        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL);

        $menu->addArray(array('url' => Horde::applicationUrl('forms.php'), 'text' => _("_List Forms"), 'icon' => 'ulaform.png'));
        $menu->addArray(array('url' => Horde::applicationUrl('edit.php'), 'text' => _("_New Form"), 'icon' => 'new.png'));

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
