<?php
/**
 * This Ulaform script allows for the fields in a form to be sorted in
 * a specific order, using the standard Horde_Form sorter field.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: ulaform/sortfields.php,v 1.24 2005/01/03 14:35:39 jan Exp $
 */

@define('ULAFORM_BASE', dirname(__FILE__));
require_once ULAFORM_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$form_id = $vars->get('form_id');
$formname = $vars->get('formname');
$fields = $ulaform->getFieldsArray($form_id);

/* Set up the form object. */
$sortform = Horde_Form::singleton('', $vars, _("Sort Fields"));

/* Set up the form. */
$sortform->setButtons(_("Save"));
$sortform->addVariable(_("Select the sort order of the fields"), 'field_order', 'sorter', false, false, null, array($fields, 12));
$sortform->addHidden('', 'form_id', 'int', true);

if ($formname) {
    $sortform->validate($vars);

    if ($sortform->isValid()) {
        $sortform->getInfo($vars, $info);
        $sort = $ulaform->sortFields($info);
        if (is_a($sort, 'PEAR_Error')) {
            Horde::logMessage($sort, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Error saving fields. %s."), $sort->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Field sort order saved."), 'horde.success');
            $url = Horde::applicationUrl('fields.php', true);
            header('Location: ' . Util::addParameter($url, array('form_id' => $form_id), null, false));
            exit;
        }
    }
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($sortform, 'renderActive'), $renderer, $vars, 'sortfields.php', 'post');

$template->set('main', $main);
$template->set('menu', Ulaform::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require ULAFORM_TEMPLATES . '/common-header.inc';
echo $template->fetch(ULAFORM_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
